@@ -51,17 +51,16 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
 
-    Transaction *transactionFromIndex(const QModelIndex &index) const;
     Q_SCRIPTABLE Transaction *transactionFromResource(AbstractResource *resource) const;
     QModelIndex indexOf(Transaction *trans) const;
     QModelIndex indexOf(AbstractResource *res) const;
 
     void addTransaction(Transaction *trans);
-    void cancelTransaction(Transaction *trans);
     void removeTransaction(Transaction *trans);
 
     bool contains(Transaction* transaction) const { return m_transactions.contains(transaction); }
     int progress() const;
+    QVector<Transaction *> transactions() const { return m_transactions; }
 
 private:
     QVector<Transaction *> m_transactions;
@@ -70,7 +69,6 @@ Q_SIGNALS:
     void startingFirstTransaction();
     void lastTransactionFinished();
     void transactionAdded(Transaction *trans);
-    void transactionCancelled(Transaction *trans);
     void transactionRemoved(Transaction* trans);
     void countChanged();
     void progressChanged();
